@@ -2,8 +2,8 @@
 // Modified by Yixuan Qiu
 // License: MIT
 
-#ifndef LOBPCG_SOLVER
-#define LOBPCG_SOLVER
+#ifndef SPECTRA_LOBPCG_SOLVER_H
+#define SPECTRA_LOBPCG_SOLVER_H
 
 #include <functional>
 #include <map>
@@ -130,7 +130,7 @@ private:
 
         Eigen::SimplicialLDLT<SparseMatrix> chol_MBM(M.transpose() * BM);
 
-        if (chol_MBM.info() != SUCCESSFUL)
+        if (chol_MBM.info() != Eigen::Success)
         {
             // LDLT decomposition fail
             m_info = chol_MBM.info();
@@ -164,7 +164,7 @@ private:
             true_BM = M;
         }
 
-        return SUCCESSFUL;
+        return Eigen::Success;
     }
 
     void applyConstraintsInPlace(SparseMatrix& X, SparseMatrix& Y,
@@ -221,10 +221,10 @@ private:
         return result;
     }
 
-    void sort_epairs(Vector& evalues, Matrix& evectors, int SelectionRule)
+    void sort_epairs(Vector& evalues, Matrix& evectors, SortRule SelectionRule)
     {
         std::function<bool(Scalar, Scalar)> cmp;
-        if (SelectionRule == SMALLEST_ALGE)
+        if (SelectionRule == SortRule::SmallestAlge)
             cmp = std::less<Scalar>{};
         else
             cmp = std::greater<Scalar>{};
@@ -291,12 +291,12 @@ public:
     LOBPCGSolver(const SparseMatrix& A, const SparseMatrix X) :
         m_n(A.rows()),
         m_nev(X.cols()),
-        m_info(NOT_COMPUTED),
+        A(A),
+        X(X),
         flag_with_constraints(false),
         flag_with_B(false),
         flag_with_preconditioner(false),
-        A(A),
-        X(X)
+        m_info(Eigen::InvalidInput)
     {
         if (A.rows() != X.rows() || A.rows() != A.cols())
             throw std::invalid_argument("Wrong size");
@@ -343,7 +343,7 @@ public:
 
         // Make initial vectors orthonormal
         // implicit BX declaration
-        if (orthogonalizeInPlace(X, m_B, BX) != SUCCESSFUL)
+        if (orthogonalizeInPlace(X, m_B, BX) != Eigen::Success)
         {
             max_iter = 0;
         }
@@ -353,7 +353,7 @@ public:
         // first approximation via a dense problem
         Eigen::EigenSolver<Matrix> eigs(Matrix(X.transpose() * AX));
 
-        if (eigs.info() != SUCCESSFUL)
+        if (eigs.info() != Eigen::Success)
         {
             m_info = eigs.info();
             max_iter = 0;
@@ -362,7 +362,7 @@ public:
         {
             m_evalues = eigs.eigenvalues().real();
             m_evectors = eigs.eigenvectors().real();
-            sort_epairs(m_evalues, m_evectors, SMALLEST_ALGE);
+            sort_epairs(m_evalues, m_evectors, SortRule::SmallestAlge);
             sparse_eVecX = m_evectors.sparseView();
 
             X = X * sparse_eVecX;
@@ -381,7 +381,7 @@ public:
 
             if (BlockSize == 0)
             {
-                m_info = SUCCESSFUL;
+                m_info = Eigen::Success;
                 break;
             }
 
@@ -410,7 +410,7 @@ public:
                 applyConstraintsInPlace(m_residuals, m_Y, m_B);
             }
 
-            if (orthogonalizeInPlace(m_residuals, m_B, BR) != SUCCESSFUL)
+            if (orthogonalizeInPlace(m_residuals, m_B, BR) != Eigen::Success)
             {
                 break;
             }
@@ -419,7 +419,7 @@ public:
             // Orthonormalize conjugate directions
             if (iter_num > 0)
             {
-                if (orthogonalizeInPlace(directions, m_B, BD, true) != SUCCESSFUL)
+                if (orthogonalizeInPlace(directions, m_B, BD, true) != Eigen::Success)
                 {
                     break;
                 }
@@ -448,28 +448,27 @@ public:
                 gramB = stack_4_matricies(Matrix::Identity(m_nev, m_nev), XBR, XBR.transpose(), Matrix::Identity(BlockSize, BlockSize));
             }
 
-            //calculate the lowest/largest m eigenpairs; Solve the generalized eigenvalue problem.
+            // Calculate the lowest/largest m eigenpairs; Solve the generalized eigenvalue problem.
             DenseSymMatProd<Scalar> Aop(gramA);
             DenseCholesky<Scalar> Bop(gramB);
 
-            SymGEigsSolver<Scalar, SMALLEST_ALGE, DenseSymMatProd<Scalar>,
-                           DenseCholesky<Scalar>, GEIGS_CHOLESKY>
-                geigs(&Aop, &Bop, m_nev, std::min(10, int(gramA.rows()) - 1));
+            SymGEigsSolver<DenseSymMatProd<Scalar>, DenseCholesky<Scalar>, GEigsMode::Cholesky>
+                geigs(Aop, Bop, m_nev, (std::min)(10, int(gramA.rows()) - 1));
 
             geigs.init();
-            int nconv = geigs.compute();
+            geigs.compute(SortRule::SmallestAlge);
 
-            //Mat evecs;
-            if (geigs.info() == SUCCESSFUL)
+            // Mat evecs
+            if (geigs.info() == CompInfo::Successful)
             {
                 m_evalues = geigs.eigenvalues();
                 m_evectors = geigs.eigenvectors();
-                sort_epairs(m_evalues, m_evectors, SMALLEST_ALGE);
+                sort_epairs(m_evalues, m_evectors, SortRule::SmallestAlge);
             }
             else
             {
                 // Problem With General EgenVec
-                m_info = geigs.info();
+                m_info = Eigen::NoConvergence;
                 break;
             }
 
@@ -525,7 +524,7 @@ public:
 
         if (BlockSize == 0)
         {
-            m_info = SUCCESSFUL;
+            m_info = Eigen::Success;
         }
     }  // compute
 
@@ -549,4 +548,4 @@ public:
 
 }  // namespace Spectra
 
-#endif  // LOBPCG_SOLVER
+#endif  // SPECTRA_LOBPCG_SOLVER_H
